package de.fraunhofer.iem.dataprovider.configuration.security

import org.springframework.http.HttpStatus
import org.springframework.stereotype.Component
import org.springframework.web.server.ServerWebExchange
import org.springframework.web.server.WebFilter
import org.springframework.web.server.WebFilterChain
import reactor.core.publisher.Mono

const val API_KEY_HEADER = "Api-Key"
const val API_HEADER_NOT_FOUND_MSG = "Api-Key header not found."

@Component
class ApiKeyFilter(private val securityProperties: SecurityProperties) : WebFilter {


    override fun filter(exchange: ServerWebExchange, chain: WebFilterChain): Mono<Void> {
        val apiKey = exchange.request.headers.getFirst(API_KEY_HEADER)
        return if (apiKey == null) {
            exchange.response.setStatusCode(HttpStatus.BAD_REQUEST)
            val buffer = exchange.response.bufferFactory().wrap(API_HEADER_NOT_FOUND_MSG.encodeToByteArray())
            exchange.response.writeWith(Mono.just(buffer))
        } else {
            if (apiKey != securityProperties.apiKey) {
                exchange.response.setStatusCode(HttpStatus.UNAUTHORIZED)
                exchange.response.setComplete()
            } else {
                chain.filter(exchange)
            }
        }
    }
}
